// LICENSE: GPL

#include <QtGui>

#include "TouchFreezeApp.h"
#include "TouchFreezeUI.h"
#include "EvieDaemon.h"


TouchFreezeApp::TouchFreezeApp( int argc, char* argv[] ) : QApplication( argc, argv )
{
  int delay = 500;
  if ( argc == 2 )
    delay = atoi( argv[1] );

  qDebug( "typing delay is %i ms", delay );
  QString msg = tr( "setting typing delay to" ) + QString( "%1" ).arg( delay ) + tr( "milliseconds." );

  if ( !QSystemTrayIcon::isSystemTrayAvailable() )
  {
     qDebug( "there's no system tray. Use KDE or GNOME, please!" );
     quit();
  }

  mUI = new TouchFreezeUI();
  setActiveWindow( mUI );

  mEvieDaemon = new EvieDaemon( this, delay );

  connect( mEvieDaemon, SIGNAL( keyPressed( int ) ), this, SLOT( onEventActivity() ) );
  connect( mEvieDaemon, SIGNAL( keyReleased( int ) ), this, SLOT( onEventActivity() ) );
  connect( mEvieDaemon, SIGNAL( buttonPressed( int ) ), this, SLOT( onEventActivity() ) );
  connect( mEvieDaemon, SIGNAL( buttonReleased( int ) ), this, SLOT( onEventActivity() ) );

  connect( mEvieDaemon, SIGNAL( startTyping() ), this, SLOT( onStartTyping() ) );
  connect( mEvieDaemon, SIGNAL( stopTyping() ), this, SLOT( onStopTyping() ) );

  mUI->setup( mEvieDaemon->majorVersionXevie(), mEvieDaemon->minorVersionXevie(), delay );

  connect( mUI, SIGNAL( delayChanged( unsigned int ) ), this, SLOT( onDelayChanged( unsigned int ) ) );
}

TouchFreezeApp::~TouchFreezeApp()
{
}

void TouchFreezeApp::onEventActivity()
{
// TODO
/*
  QString txt;

  if ( mEvieDaemon->hasKeyboardActivity() )
    txt = "typing...";

  if ( mEvieDaemon->hasButtonActivity() )
    txt += "clicking...";
*/
}

void TouchFreezeApp::onStartTyping()
{
  qDebug( "start typing" );
  mEvieDaemon->setButtonEventsBlocked( true );
}

void TouchFreezeApp::onStopTyping()
{
  qDebug( "stop typing" );
  mEvieDaemon->setButtonEventsBlocked( false );
}

void TouchFreezeApp::onDelayChanged( unsigned int delay )
{
  qDebug( "delay is %d ms", delay );
  mEvieDaemon->setDelay( delay );
}

