#include <QtGui>

#include "TouchFreezeUI.h"
#include "Version.h"

TouchFreezeUI::TouchFreezeUI( QWidget* parent ) : QWidget( parent ), Ui::TouchFreezeUIBase()
{
  setupUi( this );

  QSystemTrayIcon* systray = new QSystemTrayIcon( this );

  systray->setIcon( QIcon( ":/stuff/touchpad.svg" ) );
  systray->show();

  QMenu* trayMenu = new QMenu( this );
  QAction* quitAction = new QAction( tr( "&Quit" ), this );

  connect( quitAction, SIGNAL( triggered() ), qApp, SLOT( quit() ) );

  trayMenu->addAction( quitAction );
  systray->setContextMenu( trayMenu );

  systray->setToolTip( qAppName() + " - "+ tr( "a utility to avoid touch pad troubles" ) );

  connect( systray, SIGNAL( activated( QSystemTrayIcon::ActivationReason ) ),
           this, SLOT( onSystrayActivation( QSystemTrayIcon::ActivationReason ) ) );


  connect( delaySlider, SIGNAL( valueChanged( int ) ), this, SLOT( onSliderValueChange( int ) ) );
  connect( delaySpinBox, SIGNAL( valueChanged( double ) ), this, SLOT( onSpinBoxValueChange( double ) ) );

  connect( cancelPushButton, SIGNAL( clicked() ), this, SLOT( onCancel() ) );
  connect( applyPushButton, SIGNAL( clicked() ), this, SLOT( onApply() ) );
}

void TouchFreezeUI::setup( int verMaj, int verMin, unsigned int delay )
{
  QString verStr = tr( "version" );
  QString appInfoStr = "<b>" + qAppName() + "</b> " + verStr + " " + VER_STR + "<br>";
  appInfoStr += tr( "using Xevie" ) + " " + verStr + " ";
  appInfoStr += QString( "%1.%2" ).arg( verMaj ).arg( verMin ) + "<br>";
  appInfoStr += "(c) 2007 <i>Stefan Kombrink</i>";

  appInfoLabel->setText( appInfoStr );

  setWindowTitle( qAppName() + " " + VER_STR );

  delayGroupBox->setTitle( tr( "delay in seconds" ) );

  delaySlider->setMinimum( 10 );
  delaySlider->setMaximum( 2000 );
  delaySlider->setValue( delay );
  delaySlider->setSingleStep( 50 );

  const double FACTOR = 0.001;

  delaySpinBox->setMinimum( delaySlider->minimum() * FACTOR );
  delaySpinBox->setMaximum( delaySlider->maximum() * FACTOR );
  delaySpinBox->setValue( delaySlider->value() * FACTOR );
  delaySpinBox->setSingleStep( delaySlider->singleStep() * FACTOR );


  applyPushButton->setText( tr( "A&pply" ) );
  applyPushButton->setDisabled( true );

  cancelPushButton->setText( tr( "C&ancel" ) );
}

void TouchFreezeUI::onSliderValueChange( int value )
{
  const double FACTOR = 0.001;

  delaySpinBox->setValue( value * FACTOR );
  applyPushButton->setEnabled( true );
}

void TouchFreezeUI::onSpinBoxValueChange( double value )
{
  const int FACTOR = 1000;

  delaySlider->setValue( qRound( value * FACTOR ) );
  applyPushButton->setEnabled( true );
}

void TouchFreezeUI::closeEvent( QCloseEvent* e )
{
  hide();
  e->ignore();
}

void TouchFreezeUI::onSystrayActivation( QSystemTrayIcon::ActivationReason reason )
{
  if ( reason == QSystemTrayIcon::Trigger ) setVisible( !isVisible() );
}

void TouchFreezeUI::onCancel()
{
  hide();
  applyPushButton->setDisabled( true );
}

void TouchFreezeUI::onApply()
{
  hide();
  applyPushButton->setDisabled( true );
  emit delayChanged( delaySlider->value() );
}
